Index: trunk/src/org/openstreetmap/josm/gui/history/VersionInfoPanel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/history/VersionInfoPanel.java	(revision 6864)
+++ trunk/src/org/openstreetmap/josm/gui/history/VersionInfoPanel.java	(revision 6865)
@@ -3,5 +3,4 @@
 
 import static org.openstreetmap.josm.tools.I18n.tr;
-import static org.openstreetmap.josm.tools.I18n.trc;
 
 import java.awt.BorderLayout;
@@ -15,4 +14,5 @@
 import java.util.Observer;
 
+import javax.swing.JComponent;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
@@ -44,7 +44,5 @@
     private UrlLabel lblUser;
     private UrlLabel lblChangeset;
-    private JPanel pnlChangesetComment;
     private JPanel pnlChangesetSource;
-    private JLabel lblComment;
     private JLabel lblSource;
     private JTextArea lblChangesetComment;
@@ -93,8 +91,5 @@
         lblChangesetSource = buildTextArea(tr("Changeset source"));
 
-        lblComment = buildLabel(trc("comment", "<b>c</b>:"), tr("Changeset comment"), lblChangesetComment);
-        lblSource = buildLabel(trc("source", "<b>s</b>:"), tr("Changeset source"), lblChangesetSource);
-
-        pnlChangesetComment = buildTextPanel(lblComment, lblChangesetComment);
+        lblSource = buildLabel(tr("<b>Source</b>:"), tr("Changeset source"), lblChangesetSource);
         pnlChangesetSource = buildTextPanel(lblSource, lblChangesetSource);
 
@@ -110,5 +105,5 @@
         add(pnlUserAndChangeset, gc);
         gc.gridy = 2;
-        add(pnlChangesetComment, gc);
+        add(lblChangesetComment, gc);
         gc.gridy = 3;
         add(pnlChangesetSource, gc);
@@ -223,15 +218,17 @@
 
         final Changeset oppCs = model.getPointInTime(pointInTimeType.opposite()).getChangeset();
-        updateText(cs, "comment", lblChangesetComment, lblComment, oppCs, pnlChangesetComment);
+        updateText(cs, "comment", lblChangesetComment, null, oppCs, lblChangesetComment);
         updateText(cs, "source", lblChangesetSource, lblSource, oppCs, pnlChangesetSource);
     }
     
-    protected static void updateText(Changeset cs, String attr, JTextArea textArea, JLabel label, Changeset oppCs, JPanel panel) {
+    protected static void updateText(Changeset cs, String attr, JTextArea textArea, JLabel label, Changeset oppCs, JComponent container) {
         final String text = cs != null ? cs.get(attr) : null;
         // Update text, hide prefixing label if empty
-        label.setVisible(text != null && !Utils.strip(text).isEmpty());
+        if (label != null) {
+            label.setVisible(text != null && !Utils.strip(text).isEmpty());
+        }
         textArea.setText(text);
-        // Hide panel if values of both versions are empty
-        panel.setVisible(text != null || (oppCs != null && oppCs.get(attr) != null));
+        // Hide container if values of both versions are empty
+        container.setVisible(text != null || (oppCs != null && oppCs.get(attr) != null));
     }
 }
